get_cached_batch_aggregate_info

Function get_cached_batch_aggregate_info 

pub fn get_cached_batch_aggregate_info(
    subquery_ptr: usize,
) -> Option<Option<Arc<BatchAggregateLookupInfo>>>
Get cached batch aggregate lookup info by subquery pointer address. Returns Arc to avoid cloning strings on every lookup.