ExecutionContext

Struct ExecutionContext 

pub struct ExecutionContext { /* private fields */ }
Execution context for SQL queries

The execution context carries state and configuration for query execution, including parameters, transaction state, and cancellation support.

Note: This struct uses Arc for immutable shared data to make cloning cheap during correlated subquery processing where context is cloned per row.

Implementations

Source

impl ExecutionContext

pub fn new() -> Self

Create a new empty execution context Uses static defaults for empty collections to avoid allocations

pub fn with_params(params: ParamVec) -> Self

Create an execution context with positional parameters

pub fn with_named_params(named_params: FxHashMap<String, Value>) -> Self

Create an execution context with named parameters

pub fn get_param(&self, index: usize) -> Option<&Value>

Get a positional parameter by index (1-based)

pub fn get_named_param(&self, name: &str) -> Option<&Value>

Get a named parameter by name

pub fn params(&self) -> &[Value]

Get all positional parameters

pub fn params_arc(&self) -> &CompactArc<ParamVec>

Get the params Arc for zero-copy sharing. Used by evaluator bridge to avoid cloning params.

pub fn named_params(&self) -> &FxHashMap<String, Value>

Get all named parameters

pub fn named_params_arc(&self) -> &Arc<FxHashMap<String, Value>>

Get the named_params Arc for zero-copy sharing. Used by evaluator bridge to avoid cloning params.

pub fn param_count(&self) -> usize

Get the number of positional parameters

pub fn set_params(&mut self, params: ParamVec)

Set positional parameters

pub fn add_param(&mut self, value: Value)

Add a positional parameter

pub fn set_named_param(&mut self, name: impl Into<String>, value: Value)

Set a named parameter

pub fn auto_commit(&self) -> bool

Check if auto-commit is enabled

pub fn set_auto_commit(&mut self, auto_commit: bool)

Set auto-commit mode

pub fn is_cancelled(&self) -> bool

Check if the query has been cancelled

pub fn cancel(&self)

Cancel the query

pub fn cancellation_handle(&self) -> CancellationHandle

Get a cancellation handle that can be used from another thread

pub fn current_database(&self) -> Option<&str>

Get the current database/schema name

pub fn set_current_database(&mut self, database: impl Into<String>)

Set the current database/schema name

pub fn get_session_var(&self, name: &str) -> Option<&Value>

Get a session variable

pub fn set_session_var(&mut self, name: impl Into<String>, value: Value)

Set a session variable

pub fn timeout_ms(&self) -> u64

Get the query timeout in milliseconds

pub fn set_timeout_ms(&mut self, timeout_ms: u64)

Set the query timeout in milliseconds

pub fn has_timeout(&self) -> bool

Check if a timeout has been set

pub fn view_depth(&self) -> usize

Get the current view nesting depth

pub fn with_incremented_view_depth(&self) -> Self

Create a new context with incremented view depth. Used when executing nested views to track recursion depth. Also increments query_depth since views are nested queries.

pub fn with_incremented_query_depth(&self) -> Self

Create a new context with incremented query depth. Used when executing subqueries to ensure TimeoutGuard is only created at the top level.

pub fn outer_row(&self) -> Option<&FxHashMap<CompactArc<str>, Value>>

Get the outer row context for correlated subqueries

pub fn outer_columns(&self) -> Option<&[String]>

Get the outer row columns for correlated subqueries

pub fn with_outer_row( &self, outer_row: FxHashMap<CompactArc<str>, Value>, outer_columns: CompactArc<Vec<String>>, ) -> Self

Create a new context with outer row context for correlated subqueries. The outer_row maps lowercase column names (as CompactArc) to their values. NOTE: This is now cheap to clone due to Arc wrapping of immutable fields.

pub fn get_cte( &self, name: &str, ) -> Option<&(CompactArc<Vec<String>>, CompactArc<Vec<(i64, Row)>>)>

Get CTE data by name (case-insensitive) Returns Arc references to enable zero-copy sharing with joins

pub fn get_cte_by_lower( &self, name_lower: &str, ) -> Option<&(CompactArc<Vec<String>>, CompactArc<Vec<(i64, Row)>>)>

Get CTE data by name that is already lowercase. Use this when the name is known to be lowercase (e.g., from value_lower fields) to avoid redundant to_lowercase() allocation.

pub fn has_cte(&self, name: &str) -> bool

Check if context has CTE data

pub fn has_cte_by_lower(&self, name_lower: &str) -> bool

Check if context has CTE data by name that is already lowercase. Use this when the name is known to be lowercase to avoid allocation.

pub fn with_cte_data( &self, cte_data: Arc<StringMap<(CompactArc<Vec<String>>, CompactArc<Vec<(i64, Row)>>)>>, ) -> Self

Create a new context with CTE data for subqueries to reference Takes an Arc to avoid cloning large CTE datasets

pub fn transaction_id(&self) -> Option<u64>

Get the current transaction ID

pub fn set_transaction_id(&mut self, txn_id: u64)

Set the transaction ID

pub fn with_transaction_id(&self, txn_id: u64) -> Self

Create a new context with a transaction ID

pub fn check_cancelled(&self) -> Result<()>

Check for cancellation and return an error if cancelled