DistinctResult

Struct DistinctResult 

pub struct DistinctResult { /* private fields */ }
Streaming distinct result that removes duplicate rows on-the-fly

This streams rows and only stores seen row values for deduplication. This enables:

  • Early termination with LIMIT (no need to scan all rows)
  • Lower latency to first row
  • Streaming output

Implementations

Source

impl DistinctResult

pub fn new(inner: Box<dyn QueryResult>) -> Self

Create a new streaming distinct result

pub fn with_column_count( inner: Box<dyn QueryResult>, distinct_columns: Option<usize>, ) -> Self

Create a distinct result that only considers the first distinct_columns columns for uniqueness comparison. This is used when ORDER BY references columns not in SELECT.

For example: SELECT DISTINCT a FROM t ORDER BY b

  • The result has columns [a, b] for sorting
  • But distinctness should only compare column [a]