pub struct LagFunction { /* private fields */ }Expand description
LAG window function
Returns the value from a row that is offset rows before the current row
within the partition. If there is no such row, returns the default value.
Implementations
Sourceimpl LagFunction
impl LagFunction