pub struct Config {
pub path: Option<String>,
pub persistence: PersistenceConfig,
}Expand description
Configuration for the storage engine
Fields
path: Option<String>Path to the database directory If empty, database operates in memory-only mode
persistence: PersistenceConfigConfiguration options for disk persistence Only used if path is Some
Implementations
Sourceimpl Config
impl Config
Sourcepub fn with_path<P: Into<String>>(path: P) -> Self
pub fn with_path<P: Into<String>>(path: P) -> Self
Creates a new configuration with persistence at the given path
Sourcepub fn is_persistent(&self) -> bool
pub fn is_persistent(&self) -> bool
Returns true if persistence is enabled
Sourcepub fn with_persistence(self, config: PersistenceConfig) -> Self
pub fn with_persistence(self, config: PersistenceConfig) -> Self
Builder method to set persistence config