pub struct DistinctTracker { /* private fields */ }Expand description
Helper struct for tracking distinct values
Uses AHashSet
Implementations
Sourceimpl DistinctTracker
impl DistinctTracker
Sourcepub fn check_and_add(&mut self, value: &Value) -> bool
pub fn check_and_add(&mut self, value: &Value) -> bool
Check if a value has been seen before (returns true if new) Note: Caller must ensure value is not NULL before calling
Sourcepub fn check_and_add_with_null_check(&mut self, value: &Value) -> bool
pub fn check_and_add_with_null_check(&mut self, value: &Value) -> bool
Check if a value has been seen before, with null handling (returns true if new)